aboutsummaryrefslogtreecommitdiffstats
path: root/bpmn/so-bpmn-infrastructure-flows/src/test
diff options
context:
space:
mode:
authorrameshiyer27 <ramesh.murugan.iyer@est.tech>2020-07-29 18:39:01 +0100
committerrameshiyer27 <ramesh.murugan.iyer@est.tech>2020-08-26 12:23:48 +0100
commit9d8d8d99489dc92951d9e587e8fdc8f048d53e26 (patch)
tree3f7a10078b89d98f15950de3f51a5309dccd4e4f /bpmn/so-bpmn-infrastructure-flows/src/test
parentfca1c8d7124374144ec35c3685867642adf392e7 (diff)
Refactor PNF names in BPMN workflows
Issue-ID: SO-3105 Signed-off-by: zrrmmua <ramesh.murugan.iyer@est.tech> Change-Id: I8cab1afa54ea8a1981fcddcf0c25f6f86bb14421
Diffstat (limited to 'bpmn/so-bpmn-infrastructure-flows/src/test')
-rw-r--r--bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/GenericPnfSWUPDownloadTest.java (renamed from bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/PNFSWUPDownloadTest.java)18
-rw-r--r--bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/GenericPnfSoftwareUpgradeTest.java (renamed from bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/PNFSoftwareUpgradeTest.java)11
-rw-r--r--bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/ServiceLevelUpgradeTest.java2
-rw-r--r--bpmn/so-bpmn-infrastructure-flows/src/test/resources/request/GenericPnfSoftwareUpgradeTest.json (renamed from bpmn/so-bpmn-infrastructure-flows/src/test/resources/request/PNFSoftwareUpgradeTest.json)0
-rw-r--r--bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/GenericPnfSoftwareUpgradeTest.json (renamed from bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/PNFSoftwareUpgradeTest.json)0
-rw-r--r--bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/GenericPnfSoftwareUpgradeTest_catalogdb.json (renamed from bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/PNFSoftwareUpgradeTest_catalogdb.json)0
6 files changed, 17 insertions, 14 deletions
diff --git a/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/ServiceLevelUpgradeTest.java b/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/ServiceLevelUpgradeTest.java
index 00dda299b6..bdad46f3ca 100644
--- a/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/ServiceLevelUpgradeTest.java
+++ b/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/ServiceLevelUpgradeTest.java
@@ -145,7 +145,7 @@ public class ServiceLevelUpgradeTest extends BaseBPMNTest {
}
} catch (Exception e) {
e.printStackTrace();
- fail("PNFSoftwareUpgrade request exception", e);
+ fail("GenericPnfSoftwareUpgrade request exception", e);
}
assertThat(count == actionNames.length);
}
diff --git a/bpmn/so-bpmn-infrastructure-flows/src/test/resources/request/PNFSoftwareUpgradeTest.json b/bpmn/so-bpmn-infrastructure-flows/src/test/resources/request/GenericPnfSoftwareUpgradeTest.json
index a101118623..a101118623 100644
--- a/bpmn/so-bpmn-infrastructure-flows/src/test/resources/request/PNFSoftwareUpgradeTest.json
+++ b/bpmn/so-bpmn-infrastructure-flows/src/test/resources/request/GenericPnfSoftwareUpgradeTest.json
diff --git a/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/PNFSoftwareUpgradeTest.json b/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/GenericPnfSoftwareUpgradeTest.json
index 32539844ba..32539844ba 100644
--- a/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/PNFSoftwareUpgradeTest.json
+++ b/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/GenericPnfSoftwareUpgradeTest.json
diff --git a/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/PNFSoftwareUpgradeTest_catalogdb.json b/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/GenericPnfSoftwareUpgradeTest_catalogdb.json
index faec947fec..faec947fec 100644
--- a/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/PNFSoftwareUpgradeTest_catalogdb.json
+++ b/bpmn/so-bpmn-infrastructure-flows/src/test/resources/response/GenericPnfSoftwareUpgradeTest_catalogdb.json
diff --git a/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/PNFSWUPDownloadTest.java b/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/GenericPnfSWUPDownloadTest.java
index a0ef90d7b8..b9c5fdf145 100644
--- a/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/PNFSWUPDownloadTest.java
+++ b/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/GenericPnfSWUPDownloadTest.java
@@ -49,15 +49,15 @@ import static org.assertj.core.api.Assertions.fail;
import static org.camunda.bpm.engine.test.assertions.bpmn.BpmnAwareAssertions.assertThat;
/**
* Basic Integration test for PNFSWUPDownloadTest.bpmn workflow.
*/
-public class PNFSWUPDownloadTest extends BaseBPMNTest {
+public class GenericPnfSWUPDownloadTest extends BaseBPMNTest {
private final Logger logger = LoggerFactory.getLogger(getClass());
private static final long WORKFLOW_WAIT_TIME = 1000L;
- private static final String TEST_PROCESSINSTANCE_KEY = "PNFSWUPDownload";
+ private static final String TEST_PROCESSINSTANCE_KEY = "GenericPnfSWUPDownload";
private static final AAIVersion VERSION = AAIVersion.LATEST;
private static final Map<String, Object> executionVariables = new HashMap();
private final String[] actionNames = new String[3];
@@ -76,8 +76,8 @@ public class PNFSWUPDownloadTest extends BaseBPMNTest {
executionVariables.clear();
- requestObject = FileUtil.readResourceFile("request/PNFSoftwareUpgradeTest.json");
- responseObject = FileUtil.readResourceFile("response/PNFSoftwareUpgradeTest.json");
+ requestObject = FileUtil.readResourceFile("request/GenericPnfSoftwareUpgradeTest.json");
+ responseObject = FileUtil.readResourceFile("response/GenericPnfSoftwareUpgradeTest.json");
executionVariables.put("bpmnRequest", requestObject);
@@ -136,7 +136,7 @@ public class PNFSWUPDownloadTest extends BaseBPMNTest {
}
} catch (Exception e) {
e.printStackTrace();
- fail("PNFSWUPDownload request exception", e);
+ fail("GenericPnfSWUPDownload request exception", e);
}
assertThat(count == actionNames.length);
}
@@ -152,7 +152,8 @@ public class PNFSWUPDownloadTest extends BaseBPMNTest {
ActionIdentifiers actionIdentifiers = executionServiceInput.getActionIdentifiers();
/**
* the fields of actionIdentifiers should match the one in the response/PNFSoftwareUpgrade_catalogdb.json.
*/
Assertions.assertThat(actionIdentifiers.getBlueprintName()).isEqualTo("test_pnf_software_upgrade_restconf");
Assertions.assertThat(actionIdentifiers.getBlueprintVersion()).isEqualTo("1.0.0");
@@ -202,7 +203,8 @@ public class PNFSWUPDownloadTest extends BaseBPMNTest {
*/
private void mockCatalogDb() {
- String catalogdbClientResponse = FileUtil.readResourceFile("response/PNFSoftwareUpgradeTest_catalogdb.json");
+ String catalogdbClientResponse =
+ FileUtil.readResourceFile("response/GenericPnfSoftwareUpgradeTest_catalogdb.json");
/**
@@ -49,15 +49,15 @@ import static org.assertj.core.api.Assertions.fail;
import static org.camunda.bpm.engine.test.assertions.bpmn.BpmnAwareAssertions.assertThat;
/**
- * Basic Integration test for PNFSWUPDownloadTest.bpmn workflow.
+ * Basic Integration test for GenericPnfSWUPDownloadTest.bpmn workflow.
*/
@@ -152,7 +152,8 @@ public class PNFSWUPDownloadTest extends BaseBPMNTest {
ActionIdentifiers actionIdentifiers = executionServiceInput.getActionIdentifiers();
/**
- * the fields of actionIdentifiers should match the one in the response/PNFSoftwareUpgrade_catalogdb.json.
+ * the fields of actionIdentifiers should match the one in the
+ * response/GenericPnfSoftwareUpgradeTest_catalogdb.json.
*/
Assertions.assertThat(actionIdentifiers.getBlueprintName()).isEqualTo("test_pnf_software_upgrade_restconf");
diff --git a/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/PNFSoftwareUpgradeTest.java b/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/GenericPnfSoftwareUpgradeTest.java
index 0bf14d7443..de81f91e66 100644
--- a/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/PNFSoftwareUpgradeTest.java
+++ b/bpmn/so-bpmn-infrastructure-flows/src/test/java/org/onap/so/bpmn/infrastructure/process/GenericPnfSoftwareUpgradeTest.java
@@ -49,15 +49,15 @@ import static org.assertj.core.api.Assertions.fail;
import static org.camunda.bpm.engine.test.assertions.bpmn.BpmnAwareAssertions.assertThat;
/**
* Basic Integration test for PNFSoftwareUpgrade.bpmn workflow.
*/
-public class PNFSoftwareUpgradeTest extends BaseBPMNTest {
+public class GenericPnfSoftwareUpgradeTest extends BaseBPMNTest {
private final Logger logger = LoggerFactory.getLogger(getClass());
private static final long WORKFLOW_WAIT_TIME = 1000L;
- private static final String TEST_PROCESSINSTANCE_KEY = "PNFSoftwareUpgrade";
+ private static final String TEST_PROCESSINSTANCE_KEY = "GenericPnfSoftwareUpgrade";
private static final AAIVersion VERSION = AAIVersion.LATEST;
private static final Map<String, Object> executionVariables = new HashMap();
private static final String REQUEST_ID = "50ae41ad-049c-4fe2-9950-539f111120f5";
@@ -140,7 +140,7 @@ public class PNFSoftwareUpgradeTest extends BaseBPMNTest {
}
} catch (Exception e) {
e.printStackTrace();
- fail("PNFSoftwareUpgrade request exception", e);
+ fail("GenericPnfSoftwareUpgrade request exception", e);
}
assertThat(count == actionNames.length);
}
@@ -156,7 +156,8 @@ public class PNFSoftwareUpgradeTest extends BaseBPMNTest {
ActionIdentifiers actionIdentifiers = executionServiceInput.getActionIdentifiers();
/**
* the fields of actionIdentifiers should match the one in the response/PNFSoftwareUpgrade_catalogdb.json.
*/
assertThat(actionIdentifiers.getBlueprintName()).isEqualTo("test_pnf_software_upgrade_restconf");
assertThat(actionIdentifiers.getBlueprintVersion()).isEqualTo("1.0.0");
@@ -49,15 +49,15 @@ import static org.assertj.core.api.Assertions.fail;
import static org.camunda.bpm.engine.test.assertions.bpmn.BpmnAwareAssertions.assertThat;
/**
- * Basic Integration test for PNFSoftwareUpgrade.bpmn workflow.
+ * Basic Integration test for GenericPnfSoftwareUpgrade.bpmn workflow.
*/
@@ -156,7 +156,8 @@ public class PNFSoftwareUpgradeTest extends BaseBPMNTest {
ActionIdentifiers actionIdentifiers = executionServiceInput.getActionIdentifiers();
/**
- * the fields of actionIdentifiers should match the one in the response/PNFSoftwareUpgrade_catalogdb.json.
+ * the fields of actionIdentifiers should match the one in the
+ * response/GenericPnfSoftwareUpgrade_catalogdb.json.
*/
assertThat(actionIdentifiers.getBlueprintName()).isEqualTo("test_pnf_software_upgrade_restconf");